From: "Krzysztof Helt" <krzysztof.h1@wp.pl>
To: linux-fbdev-devel <linux-fbdev-devel@lists.sourceforge.net>
Subject: [PATCH] skeletonfb: improvements
Date: Fri, 04 May 2007 19:12:24 +0200 [thread overview]
Message-ID: <463b6978c449f@wp.pl> (raw)
[-- Attachment #1: Type: text/plain, Size: 1805 bytes --]
From: Krzysztof Helt <krzysztof.h1@wp.pl>
This patch adds a macro to register PCI ids table and corrects
type of xxxfb_fix variable to avoid modpost warnings.
Signed-off-by: Krzysztof Helt <krzysztof.h1@wp.pl>
---
--- linux-2.6.21.orig/drivers/video/skeletonfb.c 2007-05-04
10:20:25.000000000 +0200
+++ linux-2.6.21/drivers/video/skeletonfb.c 2007-05-04 10:17:
21.000000000 +0200
@@ -84,7 +84,7 @@ struct xxx_par;
* if we don't use modedb. If we do use modedb see xxxfb_init
how to use it
* to get a fb_var_screeninfo. Otherwise define a default var as
well.
*/
-static struct fb_fix_screeninfo xxxfb_fix __initdata = {
+static struct fb_fix_screeninfo xxxfb_fix __devinitdata = {
.id = "FB's name",
.type = FB_TYPE_PACKED_PIXELS,
.visual = FB_VISUAL_PSEUDOCOLOR,
@@ -705,7 +705,7 @@ static int __devinit xxxfb_probe(struct
info->screen_base = framebuffer_virtual_memory;
info->fbops = &xxxfb_ops;
info->fix = xxxfb_fix; /* this will be the only time
xxxfb_fix will be
- * used, so mark it as __initdata
+ * used, so mark it as __devinitdata
*/
info->pseudo_palette = pseudo_palette; /* The pseudopalette
is an
* 16-member array
@@ -900,6 +900,8 @@ static struct pci_driver xxxfb_driver =
.resume = xxxfb_resume, /* optional but recommended */
};
+MODULE_DEVICE_TABLE(pci, xxxfb_id_table);
+
int __init xxxfb_init(void)
{
/*
----------------------------------------------------
Już niedługo pierwsza komunia! Zrób naprawdę niezapomniany prezent:
Pięknie wydany i zilustrowany album do uzupełnienia przez dziecko
będzie na całe życie kroniką Pierwszej Komunii Świętej - Zobacz:
http://klik.wp.pl/?adr=http%3A%2F%2Fadv.reklama.wp.pl%2Fas%2Fkom.html&sid=1125
[-- Attachment #2: skeletonfb-improvements.diff --]
[-- Type: application/octet-stream, Size: 1194 bytes --]
--- linux-2.6.21.orig/drivers/video/skeletonfb.c 2007-05-04 10:20:25.000000000 +0200
+++ linux-2.6.21/drivers/video/skeletonfb.c 2007-05-04 10:17:21.000000000 +0200
@@ -84,7 +84,7 @@ struct xxx_par;
* if we don't use modedb. If we do use modedb see xxxfb_init how to use it
* to get a fb_var_screeninfo. Otherwise define a default var as well.
*/
-static struct fb_fix_screeninfo xxxfb_fix __initdata = {
+static struct fb_fix_screeninfo xxxfb_fix __devinitdata = {
.id = "FB's name",
.type = FB_TYPE_PACKED_PIXELS,
.visual = FB_VISUAL_PSEUDOCOLOR,
@@ -705,7 +705,7 @@ static int __devinit xxxfb_probe(struct
info->screen_base = framebuffer_virtual_memory;
info->fbops = &xxxfb_ops;
info->fix = xxxfb_fix; /* this will be the only time xxxfb_fix will be
* used, so mark it as __initdata
*/
info->pseudo_palette = pseudo_palette; /* The pseudopalette is an
* 16-member array
@@ -900,6 +900,8 @@ static struct pci_driver xxxfb_driver =
.resume = xxxfb_resume, /* optional but recommended */
};
+MODULE_DEVICE_TABLE(pci, xxxfb_id_table);
+
int __init xxxfb_init(void)
{
/*
[-- Attachment #3: Type: text/plain, Size: 286 bytes --]
-------------------------------------------------------------------------
This SF.net email is sponsored by DB2 Express
Download DB2 Express C - the FREE version of DB2 express and take
control of your XML. No limits. Just data. Click to get it now.
http://sourceforge.net/powerbar/db2/
[-- Attachment #4: Type: text/plain, Size: 182 bytes --]
_______________________________________________
Linux-fbdev-devel mailing list
Linux-fbdev-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/linux-fbdev-devel
reply other threads:[~2007-05-04 17:12 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=463b6978c449f@wp.pl \
--to=krzysztof.h1@wp.pl \
--cc=linux-fbdev-devel@lists.sourceforge.net \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -705,7 +705,7 @@ static int __devinit xxxfb_probe(struct
info->fbops = &xxxfb_ops;
info->fix = xxxfb_fix; /* this will be the only time xxxfb_fix will be
- * used, so mark it as __initdata
+ * used, so mark it as __devinitdata
*/
info->pseudo_palette = pseudo_palette; /* The pseudopalette is an
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.